@@ -5,11 +5,15 @@
 # more info on the M3U file format available here:
 # http://n4k3d.com/the-m3u-file-format/
 
+from typing import List, Union
+
 from soco_cli.utils import error_report
 
 
 class Track:
-    def __init__(self, length, title, path):
+    def __init__(
+        self, length: Union[str, None], title: Union[str, None], path: Union[str, None]
+    ) -> None:
         self.length = length
         self.title = title
         self.path = path
@@ -22,14 +26,14 @@ class Track:
 # file name - relative or absolute path of file
 
 
-def parse_m3u(m3u_file):
+def parse_m3u(m3u_file: str) -> List[Track]:
     with open(m3u_file, "r") as infile:
         # Parse file contents. Files with an M3U/M3U8 extension must follow conventions.
         if m3u_file.lower().endswith(".m3u") or m3u_file.lower().endswith(".m3u8"):
             line = infile.readline()
             if not line.startswith("#EXTM3U"):
                 error_report("File '{}' lacks '#EXTM3U' as first line".format(m3u_file))
-                return None
+                return []
 
         playlist = []
         song = Track(None, None, None)
